UI side function to generate the snackbar html.
snackbar(id, message, includeRemoveButton = TRUE, class = "",
style = "")A length 1 character vector. The unique id of the snackbar. This needs to match up with
the id argument specified in the serve side call to showSnackbar().
the text message to display in the snackbar
whether or not to show the remove button on the right side of the snackbar
A length 1 character vector of CSS classes to add to the snackbar.
A length 1 character vector of CSS styles to add to the snackbar.