This is a wrapper for snackbar. It provides green success styling for the snackbar.
snackbarSuccess(id, message, includeRemoveButton = TRUE)A length 1 character vector. The unique id of the snackbar. This needs to match up with
the id argument specified in the serve side call to showSnackbar().
the text message to display in the snackbar
whether or not to show the remove button on the right side of the snackbar
Other snackbar wrappers: snackbarDanger,
snackbarWarning